FlattenedDependencies

Struct FlattenedDependencies 

pub struct FlattenedDependencies<'a> { /* private fields */ }
A wrapper around the directed, acyclic graph of system edges.

This allows tracking mutations to the graph for recording build pass changes.

Implementations

Source

impl FlattenedDependencies<'_>

pub fn add_edge(&mut self, system_1: SystemKey, system_2: SystemKey)

Adds an edge to the dependencies such that system_1 runs before system_2.

pub fn remove_edge(&mut self, system_1: SystemKey, system_2: SystemKey)

Removes an edge going from system_1 to system_2 in the dependencies.

This should be used with caution - removing edges this way can lead to very surprising behavior. However, this function can be used to remove dependencies that are made redundant by added edges.

Note: these edges are not reported like the added edges are.

pub fn toposort( &mut self, ) -> Result<&[SystemKey], DiGraphToposortError<SystemKey>>

Returns a topological ordering of the graph, computing it if the graph is dirty.

This function matches Dag::toposort.

pub fn toposort_and_graph( &mut self, ) -> Result<(&[SystemKey], &DiGraph<SystemKey>), DiGraphToposortError<SystemKey>>

Returns both the topological ordering and the underlying graph, computing the toposort if the graph is dirty.

This function matches Dag::toposort_and_graph.

pub fn analyze( &mut self, ) -> Result<DagAnalysis<SystemKey>, DiGraphToposortError<SystemKey>>

Processes the DAG and computes various properties about it.

This function matches Dag::analyze.

Methods from Deref<Target = Dag<SystemKey>>

pub fn graph(&self) -> &DiGraph<N, S>

Read-only access to the underlying directed graph.

pub fn is_dirty(&self) -> bool

Returns whether the graph is dirty (i.e., has been modified since the last topological sort).

pub fn is_toposorted(&self) -> bool

Returns whether the graph is topologically sorted (i.e., not dirty).

pub fn get_toposort(&self) -> Option<&[N]>

Returns the cached toposort if the graph is not dirty, otherwise returns None.