pub type AndEager<A, B> = CombinatorSystem<AndEagerMarker, A, B>;Expand description
Combines the outputs of two systems using the & operator (eagerly evaluated).
Aliased Type
pub struct AndEager<A, B> { /* private fields */ }pub type AndEager<A, B> = CombinatorSystem<AndEagerMarker, A, B>;Combines the outputs of two systems using the & operator (eagerly evaluated).
pub struct AndEager<A, B> { /* private fields */ }