pub type AndThen<A, B> = CombinatorSystem<AndThenMarker, A, B>;Expand description
Combines the outputs of two systems using the && operator (short-circuiting).
Aliased Type
pub struct AndThen<A, B> { /* private fields */ }pub type AndThen<A, B> = CombinatorSystem<AndThenMarker, A, B>;Combines the outputs of two systems using the && operator (short-circuiting).
pub struct AndThen<A, B> { /* private fields */ }