pub type NorElse<A, B> = CombinatorSystem<NorElseMarker, A, B>;Expand description
Combines and inverts the outputs of two systems using the || and ! operators (short-circuiting).
Aliased Type
pub struct NorElse<A, B> { /* private fields */ }pub type NorElse<A, B> = CombinatorSystem<NorElseMarker, A, B>;Combines and inverts the outputs of two systems using the || and ! operators (short-circuiting).
pub struct NorElse<A, B> { /* private fields */ }