pub type OrEager<A, B> = CombinatorSystem<OrEagerMarker, A, B>;Expand description
Combines the outputs of two systems using the | operator (short-circuiting).
Aliased Type
pub struct OrEager<A, B> { /* private fields */ }pub type OrEager<A, B> = CombinatorSystem<OrEagerMarker, A, B>;Combines the outputs of two systems using the | operator (short-circuiting).
pub struct OrEager<A, B> { /* private fields */ }