pub type OrElse<A, B> = CombinatorSystem<OrElseMarker, A, B>;Expand description
Combines the outputs of two systems using the || operator (short-circuiting).
Aliased Type
pub struct OrElse<A, B> { /* private fields */ }pub type OrElse<A, B> = CombinatorSystem<OrElseMarker, A, B>;Combines the outputs of two systems using the || operator (short-circuiting).
pub struct OrElse<A, B> { /* private fields */ }