pub type Xnor<A, B> = CombinatorSystem<XnorMarker, A, B>;Expand description
Combines and inverts the outputs of two systems using the ^ and ! operators (eagerly evaluated).
Aliased Type
pub struct Xnor<A, B> { /* private fields */ }pub type Xnor<A, B> = CombinatorSystem<XnorMarker, A, B>;Combines and inverts the outputs of two systems using the ^ and ! operators (eagerly evaluated).
pub struct Xnor<A, B> { /* private fields */ }