pub trait SystemExecutor: Send + Sync {
// Required methods
fn init(&mut self, schedule: &SystemSchedule);
fn run(
&mut self,
schedule: &mut SystemSchedule,
world: &mut World,
skip_systems: Option<&FixedBitSet>,
error_handler: fn(BevyError, ErrorContext),
);
fn set_apply_final_deferred(&mut self, value: bool);
}Expand description
Types that can run a SystemSchedule on a World.
Required Methods
Sourcefn init(&mut self, schedule: &SystemSchedule)
fn init(&mut self, schedule: &SystemSchedule)
Called once after the schedule is built or rebuilt.
Sourcefn run(
&mut self,
schedule: &mut SystemSchedule,
world: &mut World,
skip_systems: Option<&FixedBitSet>,
error_handler: fn(BevyError, ErrorContext),
)
fn run( &mut self, schedule: &mut SystemSchedule, world: &mut World, skip_systems: Option<&FixedBitSet>, error_handler: fn(BevyError, ErrorContext), )
Runs the systems in the schedule.
Sourcefn set_apply_final_deferred(&mut self, value: bool)
fn set_apply_final_deferred(&mut self, value: bool)
Sets whether deferred system buffers should be applied after all systems have run.